==> vtk6-6.3.0-11-armv6h.pkg.tar.xz: vtk/vtkExtentTranslator.java <==
// java wrapper for vtkExtentTranslator object
//

package vtk;
import vtk.*;

public class vtkExtentTranslator extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_2(id0,id1,id2,id3,id4,id5); }

  private native void SetWholeExtent_3(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_3(id0); }

  private native int[]  GetWholeExtent_4();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_4(); }

  private native void SetExtent_5(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetExtent_5(id0,id1,id2,id3,id4,id5); }

  private native void SetExtent_6(int id0[]);
  public void SetExtent(int id0[])
    { SetExtent_6(id0); }

  private native int[]  GetExtent_7();
  public int[]  GetExtent()
    { return GetExtent_7(); }

  private native void SetPiece_8(int id0);
  public void SetPiece(int id0)
    { SetPiece_8(id0); }

  private native int GetPiece_9();
  public int GetPiece()
    { return GetPiece_9(); }

  private native void SetNumberOfPieces_10(int id0);
  public void SetNumberOfPieces(int id0)
    { SetNumberOfPieces_10(id0); }

  private native int GetNumberOfPieces_11();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_11(); }

  private native void SetGhostLevel_12(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_12(id0); }

  private native int GetGhostLevel_13();
  public int GetGhostLevel()
    { return GetGhostLevel_13(); }

  private native int PieceToExtent_14();
  public int PieceToExtent()
    { return PieceToExtent_14(); }

  private native int PieceToExtentByPoints_15();
  public int PieceToExtentByPoints()
    { return PieceToExtentByPoints_15(); }

  private native void SetSplitModeToBlock_16();
  public void SetSplitModeToBlock()
    { SetSplitModeToBlock_16(); }

  private native void SetSplitModeToXSlab_17();
  public void SetSplitModeToXSlab()
    { SetSplitModeToXSlab_17(); }

  private native void SetSplitModeToYSlab_18();
  public void SetSplitModeToYSlab()
    { SetSplitModeToYSlab_18(); }

  private native void SetSplitModeToZSlab_19();
  public void SetSplitModeToZSlab()
    { SetSplitModeToZSlab_19(); }

  private native int GetSplitMode_20();
  public int GetSplitMode()
    { return GetSplitMode_20(); }

  private native long UPDATE_SPLIT_MODE_21();
  public vtkInformationIntegerRequestKey UPDATE_SPLIT_MODE() {
    long temp = UPDATE_SPLIT_MODE_21();

    if (temp == 0) return null;
    return (vtkInformationIntegerRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkExtentTranslator() { super(); }

  public vtkExtentTranslator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkExtentTranslator.java <==
// java wrapper for vtkExtentTranslator object
//

package vtk;
import vtk.*;

public class vtkExtentTranslator extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_2(id0,id1,id2,id3,id4,id5); }

  private native void SetWholeExtent_3(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_3(id0); }

  private native int[]  GetWholeExtent_4();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_4(); }

  private native void SetExtent_5(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetExtent_5(id0,id1,id2,id3,id4,id5); }

  private native void SetExtent_6(int id0[]);
  public void SetExtent(int id0[])
    { SetExtent_6(id0); }

  private native int[]  GetExtent_7();
  public int[]  GetExtent()
    { return GetExtent_7(); }

  private native void SetPiece_8(int id0);
  public void SetPiece(int id0)
    { SetPiece_8(id0); }

  private native int GetPiece_9();
  public int GetPiece()
    { return GetPiece_9(); }

  private native void SetNumberOfPieces_10(int id0);
  public void SetNumberOfPieces(int id0)
    { SetNumberOfPieces_10(id0); }

  private native int GetNumberOfPieces_11();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_11(); }

  private native void SetGhostLevel_12(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_12(id0); }

  private native int GetGhostLevel_13();
  public int GetGhostLevel()
    { return GetGhostLevel_13(); }

  private native int PieceToExtent_14();
  public int PieceToExtent()
    { return PieceToExtent_14(); }

  private native int PieceToExtentByPoints_15();
  public int PieceToExtentByPoints()
    { return PieceToExtentByPoints_15(); }

  private native void SetSplitModeToBlock_16();
  public void SetSplitModeToBlock()
    { SetSplitModeToBlock_16(); }

  private native void SetSplitModeToXSlab_17();
  public void SetSplitModeToXSlab()
    { SetSplitModeToXSlab_17(); }

  private native void SetSplitModeToYSlab_18();
  public void SetSplitModeToYSlab()
    { SetSplitModeToYSlab_18(); }

  private native void SetSplitModeToZSlab_19();
  public void SetSplitModeToZSlab()
    { SetSplitModeToZSlab_19(); }

  private native int GetSplitMode_20();
  public int GetSplitMode()
    { return GetSplitMode_20(); }

  private native long UPDATE_SPLIT_MODE_21();
  public vtkInformationIntegerRequestKey UPDATE_SPLIT_MODE() {
    long temp = UPDATE_SPLIT_MODE_21();

    if (temp == 0) return null;
    return (vtkInformationIntegerRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkExtentTranslator() { super(); }

  public vtkExtentTranslator(long id) { super(id); }
  public native long   VTKInit();

}
